diff --git a/dumux/boxmodels/1p2c/1p2cvolumevariables.hh b/dumux/boxmodels/1p2c/1p2cvolumevariables.hh
index dd04927683f6c21c7fd665480e0e7d728dbd5a7c..293f8d6a8ebee970934b8b34d1217304bf059f0b 100644
--- a/dumux/boxmodels/1p2c/1p2cvolumevariables.hh
+++ b/dumux/boxmodels/1p2c/1p2cvolumevariables.hh
@@ -131,12 +131,12 @@ public:
     static void completeFluidState(const PrimaryVariables& priVars,
                                    const Problem& problem,
                                    const Element& element,
-                                   const FVElementGeometry& elementGeometry,
+                                   const FVElementGeometry& fvGeometry,
                                    const int scvIdx,
                                    FluidState& fluidState)
     {
         Scalar T = Implementation::temperature_(priVars, problem, element,
-                                                elementGeometry, scvIdx);
+                                                fvGeometry, scvIdx);
         fluidState.setTemperature(T);
 
         fluidState.setPressure(phaseIdx, priVars[pressureIdx]);
diff --git a/test/boxmodels/3p3cni/kuevettespatialparams.hh b/test/boxmodels/3p3cni/kuevettespatialparams.hh
index f8b8620e88bf900d7d26366956779fdf25bd64ac..bd7fb531d874ed5ab2e24a337db9bd4b567aa251 100644
--- a/test/boxmodels/3p3cni/kuevettespatialparams.hh
+++ b/test/boxmodels/3p3cni/kuevettespatialparams.hh
@@ -221,7 +221,7 @@ public:
      * This is only required for non-isothermal models.
      *
      * \param element The finite element
-     * \param fvElemGeom The finite volume geometry
+     * \param fvGeomtry The finite volume geometry
      * \param scvIdx The local index of the sub-control volume where
      *                    the heat capacity needs to be defined
      */
diff --git a/test/boxmodels/3p3cni/columnxylolspatialparams.hh b/test/boxmodels/3p3cni/columnxylolspatialparams.hh
index 89a28eed56af6a123c6b12ad8bec31c50c0b9482..febf9e4a36ee8478346a9673a2a9e402962afe71 100644
--- a/test/boxmodels/3p3cni/columnxylolspatialparams.hh
+++ b/test/boxmodels/3p3cni/columnxylolspatialparams.hh
@@ -188,10 +188,10 @@ public:
      *                    the porosity needs to be defined
      */
     double porosity(const Element &element,
-                    const FVElementGeometry &fvGeomtry,
+                    const FVElementGeometry &fvGeometry,
                     const int scvIdx) const
     {
-        const GlobalPosition &pos = fvGeomtry.subContVol[scvIdx].global;
+        const GlobalPosition &pos = fvGeometry.subContVol[scvIdx].global;
         if (isFineMaterial_(pos))
             return finePorosity_;
         else
@@ -203,14 +203,14 @@ public:
      * \brief return the parameter object for the Brooks-Corey material law which depends on the position
      *
      * \param element The current finite element
      * \param fvGeomtry The current finite volume geometry of the element
      * \param scvIdx The index of the sub-control volume
      */
     const MaterialLawParams& materialLawParams(const Element &element,
-                                               const FVElementGeometry &fvGeomtry,
+                                               const FVElementGeometry &fvGeometry,
                                                const int scvIdx) const
     {
-        const GlobalPosition &pos = fvGeomtry.subContVol[scvIdx].global;
+        const GlobalPosition &pos = fvGeometry.subContVol[scvIdx].global;
         if (isFineMaterial_(pos))
             return fineMaterialParams_;
         else
@@ -223,21 +223,21 @@ public:
      * This is only required for non-isothermal models.
      *
      * \param element The finite element
      * \param fvGeomtry The finite volume geometry
      * \param scvIdx The local index of the sub-control volume where
      *                    the heat capacity needs to be defined
      */
     double heatCapacity(const Element &element,
-                        const FVElementGeometry &fvGeomtry,
+                        const FVElementGeometry &fvGeometry,
                         const int scvIdx) const
     {
-        const GlobalPosition &pos = fvGeomtry.subContVol[scvIdx].global;
+        const GlobalPosition &pos = fvGeometry.subContVol[scvIdx].global;
         if (isFineMaterial_(pos))
             return fineHeatCap_ * 2650 // density of sand [kg/m^3]
-                * (1 - porosity(element, fvGeomtry, scvIdx));
+                * (1 - porosity(element, fvGeometry, scvIdx));
         else
             return coarseHeatCap_ * 2650 // density of sand [kg/m^3]
-                * (1 - porosity(element, fvGeomtry, scvIdx));
+                * (1 - porosity(element, fvGeometry, scvIdx));
     }
 
     /*!
@@ -251,7 +251,7 @@ public:
      * \param elemVolVars The volume variables
      * \param tempGrad The temperature gradient
      * \param element The current finite element
      * \param fvGeomtry The finite volume geometry of the current element
      * \param faceIdx The local index of the sub-control volume face where
      *                    the matrix heat flux should be calculated
      */
@@ -260,7 +260,7 @@ public:
                         const ElementVolumeVariables &elemVolVars,
                         const DimVector &tempGrad,
                         const Element &element,
-                        const FVElementGeometry &fvGeomtry,
+                        const FVElementGeometry &fvGeometry,
                         int faceIdx) const
     {
         static const Scalar ldry = 0.35;
@@ -268,8 +268,8 @@ public:
         static const Scalar lSn1 = 0.65;
 
         // arithmetic mean of the liquid saturation and the porosity
-        const int i = fvGeomtry.subContVolFace[faceIdx].i;
-        const int j = fvGeomtry.subContVolFace[faceIdx].j;
+        const int i = fvGeometry.subContVolFace[faceIdx].i;
+        const int j = fvGeometry.subContVolFace[faceIdx].j;
         Scalar Sw = std::max(0.0, (elemVolVars[i].saturation(wPhaseIdx) +
                                    elemVolVars[j].saturation(wPhaseIdx)) / 2);
         Scalar Sn = std::max(0.0, (elemVolVars[i].saturation(nPhaseIdx) +
@@ -203,14 +203,14 @@ public:
      *
      * \param element The current finite element
-     * \param fvGeomtry The current finite volume geometry of the element
+     * \param fvGeometry The current finite volume geometry of the element
      * \param scvIdx The index of the sub-control volume
      */
@@ -223,21 +223,21 @@ public:
      *
      * \param element The finite element
-     * \param fvGeomtry The finite volume geometry
+     * \param fvGeometry The finite volume geometry
      * \param scvIdx The local index of the sub-control volume where
      *                    the heat capacity needs to be defined
@@ -251,7 +251,7 @@ public:
      * \param tempGrad The temperature gradient
      * \param element The current finite element
-     * \param fvGeomtry The finite volume geometry of the current element
+     * \param fvGeometry The finite volume geometry of the current element
      * \param faceIdx The local index of the sub-control volume face where
      *                    the matrix heat flux should be calculated